/*  &copy; Copyright 2012 by Al Williams (al.williams@awce.com) 
    Distributed under the terms of the GNU Lesser General Public License */

/*! 
 * \file gp3.cpp
 * \author Al Williams
 * \date 20 Nov 2012
 * \brief Main library source for GP3/Arduino
 *
 * The GP3/Arduino is a coprocessor for the 
 * Arduino that adds additional analog and
 * digital I/O easily via two Arduino pins

    This file is part of GP3/Arduino.

    LWOS is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.


 */
#ifndef __GP3_H
#define __GP3_H
#include <Arduino.h>
#include <SoftwareSerial.h>

//! The main class for the I/O board
class GP3
{
 private:
  SoftwareSerial *sport; 
  Stream *port;
  void setarg(unsigned int arg);
  int timeout;
  int err;
  int achannel;
public:
  GP3(int rx, int tx);
  GP3(Stream &port);
  ~GP3();
  int getError(void);
  void clearError(void);
  int readByte(void);
  unsigned int readWord(void);
  void setLED(boolean onoff);
  unsigned int a2d();
  void a2dChan(int chan);
  void a2dConf(bool rightjustify,int cselect);
  void high(int pin);
  void low(int pin);
  void toggle(int pin);
  int input(int pin);
  void setTris(int tris);
  int getTris(void);
  void setPins(int byte);
  int getPins(void);
  void writeEE(int address, int byte);
  int readEE(int address);
  void pwm(int chan, int dc, int  dfreq);
  unsigned int count(int pin, unsigned int ms);
  unsigned int rcTime(int pin, int state);
  unsigned int pulseIn(int pin, int state);
  void pulseOut(int pin, int duration);
  void freq(int pin, int ms, int frq);
  void setCounter(int prescale, int ext);
  unsigned int count();
  void resetAll(void);
  void reset(void);
  void repeat(int count);
  void argInc(void);
  void argDec(void);
  unsigned int check(void);
  void setTimeout(int _timeout);
  int getTimeout(void);
  bool listen(void);
  bool isListening();
};




#endif
